SchemaSpy - Table gnss_data.public.rinex_extra

Tables Relationships Utility Tables Constraints Anomalies Columns Donate

Table gnss_data.public.rinex_extra | Generated by SchemaSpy

Related columns Constraints Comments Legend |
Legend: |
Primary key columns
Columns with indexes
Implied relationships
Excluded column relationships
< n > number of related tables
Column | Type | Size | Nulls | Auto | Default | Children | Parents | Comments
--- | --- | --- | --- | --- | --- | --- | --- | ---
NetworkCode | varchar | 2147483647 |  |  |  |  |
stations.NetworkCode | rinex_extra_NetworkCode_fkey R
StationCode | varchar | 2147483647 |  |  |  |  |
stations.StationCode | rinex_extra_NetworkCode_fkey R
ObservationYear | numeric | 131089 |  |  |  |  |  |
ObservationMonth | numeric | 131089 |  |  |  |  |  |
ObservationDay | numeric | 131089 |  |  |  |  |  |
ObservationDOY | numeric | 131089 |  |  |  |  |  |
ObservationFYear | numeric | 131089 |  |  |  |  |  |
ObservationSTime | timestamp | 29,6 | √ |  | null |  |  |
ObservationETime | timestamp | 29,6 | √ |  | null |  |  |
ReceiverType | varchar | 20 | √ |  | null |  |  |
ReceiverSerial | varchar | 20 | √ |  | null |  |  |
ReceiverFw | varchar | 20 | √ |  | null |  |  |
AntennaType | varchar | 20 | √ |  | null |  |  |
AntennaSerial | varchar | 20 | √ |  | null |  |  |
AntennaDome | varchar | 20 | √ |  | null |  |  |
Filename | varchar | 2147483647 |  |  |  |  |  |
Interval | numeric | 131089 | √ |  | null |  |  |
AntennaOffset | numeric | 131089 | √ |  | null |  |  |
Table contained 13,308 rows at Fri Jul 28 14:55 EDT 2017

Close relationships within one two degrees of separation: